Ğ1 Lizenz - v0.2.9
===================

:Datum: 2017-08-21 16:59
:Letzte Änderung: 2018-07-14 18:05

**Lizenz für die Währung und Verpflichtung zur Übernahme von Verantwortung.**

Jede Zertifizierung für ein neues Mitglied des Ğ1 erfordert zuallererst die Übermittlung der Lizenz für die Ğ1 Währung.
Die Zertifizierer eines neuen Mitglieds müssen sicherstellen, dass die Lizenz von der zu zertifizierenden Person gelesen, verstanden und akzeptiert wurde.

Jede Informationsveranstaltung mit dem Thema Ğ1 sollte die Bestätigung der Kenntnisnahme dieser Lizenz beinhalten, diese kann durch lautes Vorlesen oder auf jedem anderen Weg übermittelt werden.

Ğ1 Netz des Vertrauens (Web of Trust) (Ğ1 WoT)
----------------------------------------------

**Hinweis:** Zertifizierung bedeutet nicht nur, sich zu vergewissern, dass man die Person kennen gelernt hat, sondern auch der gesamten Ğ1 Community Vertrauen zu geben, dass du die zu zertifizierende Person gut genug kennst und sie einfach kontaktieren kannst, für den Fall, dass eine von dir zertifizierte Person ein zweites Mitgliedskonto eröffnet hat, oder falls andere Probleme auftreten (Verschwinden der Person ...) und sie befragen kannst, um das Problem zu klären, soweit das nötig ist.

**Besonders empfohlene Hinweise**

Eine gut bekannte Person bedeutet, dass du verschiedene Wege kennst, sie zu kontaktieren: (physisch an ihrem Wohnort, per Telefon, E-Mail, etc. aber auch, dass du andere Personen kennst, die sie auch kennen und sie auch leicht erreichen können. Falls du die anderen Zertifizierer dieser Person nicht kennst, ist das ein starker Hinweis, dass du sie nicht ausreichend kennst. Eine Zertifizierung unter diesen Umständen ist ein Alarmzeichen für die Gemeinschaft.
Im Falle eines nicht ausreichenden Kennens sollte eine Zertifizierung NICHT stattfinden.

Zertifiziere niemals alleine, sondern immer zusammen mit anderen Mitgliedern des Vertrauensnetzwerks WoT, um einen Missbrauch von Software zu vermeiden. Bei jeder auftretenden Fehlermeldung, kontaktiere sofort andere (erfahrene) Mitglieder des Ğ1 WoT. (Anmerkung d, Übersetzers: die Softwareversionen von Duniter, Cesium etc. Im Jahr 2023 sind unter Umständen noch instabil und können schon mal "hängenbleiben").

Stelle sicher, dass das zukünftige, zertifizierte Mitglied die nötigen Handlungen im Konto beherrscht. Eine gute Möglichkeit ist, einige Ğ1 auf das neue Konto zu Überweisen und dann um Rücküberweisung zu deinem Konto zu bitten. Damit stellst du sicher, dass die zertifizierte Person mit Ihren Zugangsdaten (private Schlüssel) umgehen kann.

Sorge dafür, dass deine Kontakte eine aktuelle Version dieser Lizenz gelesen und verstanden haben.

Wenn du mitbekommst, dass ein Zertifizierer oder geplanter Zertifizierer eines Mitgliedskontos den Kontobesitzer nicht kennt, informiere bitte einige Experten (erfahrene Mitglieder) unter den dir bekannten Mitgliedern des WoT, zur Überprüfung des Verfahrens.

Wenn du Mitglied des Ğ1 WoT bist und ein neues Konto zertifizieren willst:

**VERGEWISSERE dich:**

**1 -** Dass du die Person (nicht nur einmal gesehen) genug kennst, um zu bestätigen, dass diese ihre Zugangdaten zu diesem öffentlichen Schlüssel sicher anwenden kann.
Siehe auch oben zu den Hinweisen "gut genug kennen".

**2 -** Dass du dich persönlich davon vergewissert hast, dass es ein guter öffentlicher Schlüssel (Zugangsdaten, Pseudonym) ist, der zertifiziert werden soll (siehe auch die Hinweise oben).

**3 -** Dass du sicher bist, dass die Person die Widerrufsdatei für ihr Duniter-Konto wirklich erzeugt, heruntergeladen und abgespeichert hat, die es im Zweifelsfall ermöglicht, die Mitgliedschaft zurückzuziehen (im Fall eines Konto-Diebstahls, Änderungen der Benutzerkennung, eines ungerechtfertigt angelegten Kontos etc.).

**4a -** Die Person im echten Leben zu treffen, um sicherzustellen, dass es diese Person ist, die das betreffende Konto (öffentlicher Schlüssel – entsprechend Der Kontonummer) handhaben kann.

**4b -** Oder verifiziere diese Person <-> den öffentlichen Schlüssel, indem du sie auf verschiedenen Wegen kontaktierst, per Post, soziale Netzwerke, Foren, Email, Videomeeting oder telefonisch. Es ist sicherer auf verschiedenen Wegen den Kontakt aufzunehmen, da man E-Mail-Konten oder ein Forums-Konto leichter hacken kann, als es für alle Kontaktmöglichkeiten möglich ist, auch ein animiertes Video mit einer animierten Stimme sind möglich.

Auf jeden Fall ist **4a** zu bevorzugen vor **4b**. Demgegenüber sind die unter **1**, **2** und **3** gemachten Anmerkungen auf jeden Fall obligatorisch.

**Regeln des Vertrauensnetzwerkes (WoT) in Kürze:**

Jedes Mitglied hat einen Vorrat von 100 gültigen Zertifizierungen, die nur einzeln alle 5 Tage vergeben (bzw. validiert) werden können.

Gültig für 2 Monate, wird die Zertifizierung eines neuen Mitglieds nur dann umgesetzt, wenn mindestens 4 weitere Zertifizierungen in dieser Zeitspanne erfolgen. Andernfalls muss der Mitgliedsantrag erneut gestellt werden.

Um ein neues Mitglied des Vertrauensnetzwerks (Ğ1 WoT) zu werden, müssen 5 Zertifizierungen erteilt werden, die einen Wert für die Berechnung der Distanzregel von mehr als 80% ergeben (Anteil der in 5 oder weniger Schritten erreichbaren Referenzmitglieder an allen Referenzmitgliedern).

Ein Mitglied des Ğ1 WoT ist Referent, wenn es mindestens Y[N] Zertifizierungen erhalten und vergeben hat, wobei N die Anzahl aller Mitglieder des WoT ist und Y[N] der Wert für "Obere Schranke(N ^ (1/5))".

Beispiele für Mitgliederzahlen:

* Für 1024 < N ≤ 3125 ergeben sich Y [N] = 5
* für 7776 < N ≤ 16807 ergeben sich Y [N] = 7
* Für 59049 < N ≤ 100 000 ergeben sich Y [N] = 10

Wenn ein neues Mitglied Teil des Ğ1 WoT geworden ist, sind seine Zertifizierungen für 2 Jahre gültig.

Um Mitglied zu bleiben, muss die Zustimmung zu dieser Lizenz regelmäßig (alle 12 Monate) mit dem privaten Schlüssel (Zugangsdaten) erneuert werden. Und es muss sichergestellt werden, dass nach 2 Jahren mindestens 5 gültige Zertifizierungen vorliegen.

Ğ1 Währung
----------

Die Ğ1 Schöpfung geschieht über eine "Universelle Dividende" für jedes menschliche Mitglied in der Form:

* 1 UD pro Person und Tag

Die Menge an UD ist gleichbleibend bis zum nächsten Stichtag (Halbjahresende /  Tag- und Nachtgleiche), wenn die UD neu berechnet wird. Dazu wird folgende Formel verwendet:

* UDtag(nächster Stichtag) = UDtag(Stichtag) + c² (M/N)(Stichtag) / (182,625 Tage)

Mit den Parametern:

* c = 4,88% / Stichtag
* UD(0) = 10,00 Ğ1

Und als Variablen:

* _M_ Die gesamte Geldmenge zum Stichtag
* _N_ die Anzahl von Mitgliedern am Stichtag

Ğ1 Software und die Ğ1 Lizenz
-----------------------------

Die verschiedenen Programme zum Umgang mit der Ğ1 Währung müssen jeweils mit einer Kopie dieser Lizenz und allen technischen Parametern der Ğ1 Währung und des Ğ1 Vertrauensnetzwerks übermittelt werden, so wie sie im ersten Block 0 des Ğ1 festgelegt wurden.

Um die technischen Details besser zu verstehen, kann man den Programmcode von Duniter untersuchen, welches eine freie Software ist. Ebenso kann man die Daten der Ğ1 Blockchain untersuchen, indem man sie über eine beliebige Duniter-Instanz oder einen Ğ1 Knoten bezieht.

Weitere Informationen sind über die Webseite des Duniter Teams [https://www.duniter.org](https://www.duniter.org) verfügbar.
